==> org-lsst-ccs-subsystem-refrig-gui-4.0.3-sources.jar: org/lsst/ccs/subsystem/refrig/ui/AuxHeaterPanel.java <==
package org.lsst.ccs.subsystem.refrig.ui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.SwingConstants;
import org.lsst.ccs.subsystem.refrig.constants.HeaterPowerState;
import org.lsst.ccs.subsystem.refrig.data.ThermalState;
import org.lsst.ccs.subsystem.refrig.ui.jas.CommandSender;

/**
 *  Implements an auxiliary heater sub-panel.
 *
 *  @author saxton
 */
public class AuxHeaterPanel extends JPanel {

    private static final String[] heaterNames = new String[ThermalState.NUM_AUX_HEATERS];
    static {
        heaterNames[ThermalState.AUX_HEATER_MINUS_Y] = "-Y";
        heaterNames[ThermalState.AUX_HEATER_PLUS_Y] = "+Y";
        heaterNames[ThermalState.AUX_HEATER_CENTER] = "Center";
    }
    private static final int switchLabelWidth, switchStateWidth, textFieldWidth;
    static {
        JLabel label = new JLabel();
        label.setFont(UiConstants.FONT);
        int width = 0;
        for (String name : heaterNames) {
            label.setText(name + ":");
            width = Math.max(width, label.getPreferredSize().width);
        }
        switchLabelWidth = width;
        width = 0;
        for (HeaterPowerState state : HeaterPowerState.values()) {
            label.setText(state.name());
            width = Math.max(width, label.getPreferredSize().width);
        }
        switchStateWidth = width;
        JTextField field = new JTextField(" 1000.0 ");
        textFieldWidth = field.getPreferredSize().width;
    }

    private final int id;
    private final CommandSender sender;

    private final JLabel switchLabel = new JLabel("");
    private final JLabel switchStatus = new JLabel("OFF");
    private final ButtonGroup switchBG = new ButtonGroup();
    private final JRadioButton switchOffRB = new JRadioButton("Off");
    private final JRadioButton switchOnRB = new JRadioButton("On");
    private final JTextField powerTextField = new JTextField();
    private final TextFieldX powerTFX = new TextFieldX(powerTextField, TextFieldX.TYPE_DOUBLE);
    private final JLabel powerUnitsLabel = new JLabel("W");


    AuxHeaterPanel(int id, CommandSender sender) {
        this.id = id;
        this.sender = sender;
        initComponents();
    }

    public void updatePanel(ThermalState rs) {
        switchStatus.setEnabled(true);
        HeaterPowerState pState = rs.getAuxHeaterState(id);
        switchStatus.setText(pState.name());
        switchStatus.setForeground(pState == HeaterPowerState.ON ? UiConstants.GREEN :
                                   pState == HeaterPowerState.DISABLD ? UiConstants.RED :
                                   pState == HeaterPowerState.OFFLINE ? UiConstants.BLUE : Color.black);
        JRadioButton selButton = pState == HeaterPowerState.ON ? switchOnRB : switchOffRB;
        selButton.setSelected(true);
        switchOffRB.setEnabled(pState == HeaterPowerState.ON);
        switchOnRB.setEnabled(pState == HeaterPowerState.OFF);
        powerTFX.update(rs.getAuxHeaterPower(id), true);
    }

    public void disablePanel() {
        switchStatus.setEnabled(false);
        switchOffRB.setEnabled(false);
        switchOnRB.setEnabled(false);
        powerTFX.disable();
    }

    private void initComponents() {
        switchLabel.setFont(UiConstants.FONT);
        switchLabel.setText(heaterNames[id] + ":");
        Dimension d = switchLabel.getPreferredSize();
        d.width = switchLabelWidth;
        switchLabel.setPreferredSize(d);
        switchStatus.setFont(UiConstants.FONT);
        d = switchStatus.getPreferredSize();
        d.width = switchStateWidth;
        switchStatus.setPreferredSize(d);
        switchOffRB.setFont(UiConstants.FONT);
        switchOffRB.setFocusable(false);
        switchOffRB.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent evt) {
                setHeaterPowerState(0);
            }
        });
        switchOnRB.setFont(UiConstants.FONT);
        switchOnRB.setFocusable(false);
        switchOnRB.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent evt) {
                setHeaterPowerState(1);
            }
        });
        switchBG.add(switchOffRB);
        switchBG.add(switchOnRB);

        d = powerTextField.getPreferredSize();
        d.width = textFieldWidth;
        powerTextField.setPreferredSize(d);
        powerTextField.setHorizontalAlignment(SwingConstants.CENTER);
        powerTextField.setText("...");
        powerTextField.addFocusListener(new FocusAdapter() {
            @Override
            public void focusLost(FocusEvent evt) {
                powerTFX.focusLost();
            }
        });
        powerTextField.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent evt) {
                Double value = (Double)powerTFX.action();
                if (value != null) {
                    sender.sendCommand(null, "setAuxHeaterPower", id, value);
                }
            }
        });
        powerTextField.addKeyListener(new KeyAdapter() {
            @Override
            public void keyTyped(KeyEvent evt) {
                powerTFX.keyTyped(evt.getKeyChar());
            }
        });
        powerUnitsLabel.setFont(UiConstants.FONT);

        // Lay out the panel
        setLayout(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.insets = new Insets(0, 0, 0, 0);
        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.anchor = GridBagConstraints.NORTHWEST;
        gbc.insets.left = 6;
        add(switchLabel, gbc);
        gbc.gridx++;
        add(switchStatus, gbc);
        gbc.gridx++;
        gbc.insets.top = -6;
        add(switchOffRB, gbc);
        gbc.gridx++;
        gbc.insets.left = 4;
        add(switchOnRB, gbc);
        gbc.gridx++;
        gbc.insets.left = 6;
        gbc.insets.top = 0;
        add(powerTextField, gbc);
        gbc.gridx++;
        gbc.insets.right = 6;
        add(powerUnitsLabel, gbc);
    }

    private void setHeaterPowerState(int value) {
        switchOffRB.setEnabled(false);
        switchOnRB.setEnabled(false);
        sender.sendCommand(null, "setAuxHeaterPowerEnable", id, value);
    }

    private static final long serialVersionUID = 1L;
}

==> org-lsst-ccs-subsystem-refrig-gui-4.0.4-sources.jar: org/lsst/ccs/subsystem/refrig/ui/AuxHeaterPanel.java <==
package org.lsst.ccs.subsystem.refrig.ui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.SwingConstants;
import org.lsst.ccs.subsystem.refrig.constants.AuxHeaterState;
import org.lsst.ccs.subsystem.refrig.data.ThermalState;
import org.lsst.ccs.subsystem.refrig.ui.jas.CommandSender;

/**
 *  Implements an auxiliary heater sub-panel.
 *
 *  @author saxton
 */
public class AuxHeaterPanel extends JPanel {

    private static final String[] heaterNames = new String[ThermalState.NUM_AUX_HEATERS];
    static {
        heaterNames[ThermalState.AUX_HEATER_MINUS_Y] = "-Y";
        heaterNames[ThermalState.AUX_HEATER_PLUS_Y] = "+Y";
        heaterNames[ThermalState.AUX_HEATER_CENTER] = "Center";
    }
    private static final int switchLabelWidth, switchStateWidth, textFieldWidth;
    static {
        JLabel label = new JLabel();
        label.setFont(UiConstants.FONT);
        int width = 0;
        for (String name : heaterNames) {
            label.setText(name + ":");
            width = Math.max(width, label.getPreferredSize().width);
        }
        switchLabelWidth = width;
        width = 0;
        for (AuxHeaterState state : AuxHeaterState.values()) {
            label.setText(state.name());
            width = Math.max(width, label.getPreferredSize().width);
        }
        switchStateWidth = width;
        JTextField field = new JTextField(" 1000.0 ");
        textFieldWidth = field.getPreferredSize().width;
    }

    private final int id;
    private final CommandSender sender;

    private final JLabel switchLabel = new JLabel("");
    private final JLabel switchStatus = new JLabel("OFF");
    private final ButtonGroup switchBG = new ButtonGroup();
    private final JRadioButton switchOffRB = new JRadioButton("Off");
    private final JRadioButton switchOnRB = new JRadioButton("On");
    private final JTextField powerTextField = new JTextField();
    private final TextFieldX powerTFX = new TextFieldX(powerTextField, TextFieldX.TYPE_DOUBLE);
    private final JLabel powerUnitsLabel = new JLabel("W");


    AuxHeaterPanel(int id, CommandSender sender) {
        this.id = id;
        this.sender = sender;
        initComponents();
    }

    public void updatePanel(ThermalState rs) {
        switchStatus.setEnabled(true);
        AuxHeaterState pState = rs.getAuxHeaterState(id);
        switchStatus.setText(pState.name());
        switchStatus.setForeground(pState == AuxHeaterState.ON ? UiConstants.GREEN :
                                   pState == AuxHeaterState.DISABLD ? UiConstants.RED :
                                   pState == AuxHeaterState.OFFLINE ? UiConstants.BLUE : Color.black);
        JRadioButton selButton = pState == AuxHeaterState.ON ? switchOnRB : switchOffRB;
        selButton.setSelected(true);
        switchOffRB.setEnabled(pState == AuxHeaterState.ON);
        switchOnRB.setEnabled(pState == AuxHeaterState.OFF);
        powerTFX.update(rs.getAuxHeaterPower(id), true);
    }

    public void disablePanel() {
        switchStatus.setEnabled(false);
        switchOffRB.setEnabled(false);
        switchOnRB.setEnabled(false);
        powerTFX.disable();
    }

    private void initComponents() {
        switchLabel.setFont(UiConstants.FONT);
        switchLabel.setText(heaterNames[id] + ":");
        Dimension d = switchLabel.getPreferredSize();
        d.width = switchLabelWidth;
        switchLabel.setPreferredSize(d);
        switchStatus.setFont(UiConstants.FONT);
        d = switchStatus.getPreferredSize();
        d.width = switchStateWidth;
        switchStatus.setPreferredSize(d);
        switchOffRB.setFont(UiConstants.FONT);
        switchOffRB.setFocusable(false);
        switchOffRB.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent evt) {
                setHeaterPowerState(0);
            }
        });
        switchOnRB.setFont(UiConstants.FONT);
        switchOnRB.setFocusable(false);
        switchOnRB.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent evt) {
                setHeaterPowerState(1);
            }
        });
        switchBG.add(switchOffRB);
        switchBG.add(switchOnRB);

        d = powerTextField.getPreferredSize();
        d.width = textFieldWidth;
        powerTextField.setPreferredSize(d);
        powerTextField.setHorizontalAlignment(SwingConstants.CENTER);
        powerTextField.setText("...");
        powerTextField.addFocusListener(new FocusAdapter() {
            @Override
            public void focusLost(FocusEvent evt) {
                powerTFX.focusLost();
            }
        });
        powerTextField.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent evt) {
                Double value = (Double)powerTFX.action();
                if (value != null) {
                    sender.sendCommand(null, "setAuxHeaterPower", id, value);
                }
            }
        });
        powerTextField.addKeyListener(new KeyAdapter() {
            @Override
            public void keyTyped(KeyEvent evt) {
                powerTFX.keyTyped(evt.getKeyChar());
            }
        });
        powerUnitsLabel.setFont(UiConstants.FONT);

        // Lay out the panel
        setLayout(new GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.insets = new Insets(0, 0, 0, 0);
        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.anchor = GridBagConstraints.NORTHWEST;
        gbc.insets.left = 6;
        add(switchLabel, gbc);
        gbc.gridx++;
        add(switchStatus, gbc);
        gbc.gridx++;
        gbc.insets.top = -6;
        add(switchOffRB, gbc);
        gbc.gridx++;
        gbc.insets.left = 4;
        add(switchOnRB, gbc);
        gbc.gridx++;
        gbc.insets.left = 6;
        gbc.insets.top = 0;
        add(powerTextField, gbc);
        gbc.gridx++;
        gbc.insets.right = 6;
        add(powerUnitsLabel, gbc);
    }

    private void setHeaterPowerState(int value) {
        switchOffRB.setEnabled(false);
        switchOnRB.setEnabled(false);
        sender.sendCommand(null, "setAuxHeaterState", id, value);
    }

    private static final long serialVersionUID = 1L;
}
